A data frame with station metadata compiled for SMNdataR.
Format
A data frame with one row per station and the following variables:
- station
Character. SMN station code.
- name
Character. Station name.
- latitude
Numeric. Decimal degrees (WGS84).
- longitude
Numeric. Decimal degrees (WGS84).
- altitude
Numeric. Elevation in meters.
- Clicom
Character. CLICOM identifier (if available).
- Referencia
Character. Reference field.
- SMN
Character. Internal SMN id (if available).
- cuenca
Character. Basin name/identifier.
- cve_sta
Character. Station code alternative.
- municipality
Character. Municipality name.
- org_cuenca
Character. Basin organization.
- organism
Character. Operating organism.
- situation
Character. Station situation/status.
- subcuenca
Character. Sub-basin.
- type
Character. Station type/class.